
**********************************************************
* Introduzione all'analisi dei dati longitudinali
* APPENDICE - breve INTRODUZIONE a Stata 
**********************************************************
* questa sintassi: 
*  appendice.do
* VERSIONE: AGOSTO 2013
**********************************************************
/*
usa: carriereIT_spell.dta
	es_factor_variables
	carriereIT_spell_m
	carriereIT_spell_f
	carriereIT_spell_lavoro
	carriereIT_spell_sd
	esempi_reddito.dta
crea: carriereIT_spell_new.dta
*/

* Per inserire dei commenti nel file della sintassi utilizziamo * per commentare una riga o altrimenti /* in apertura e */ in chiusura per blocchi interi di testo 
* Un commando troppo lungo per essere messo in una riga puo essere riportato su piu rige usando  /// 
* Tutto cio che segue  /// nella riga e considerato commento.  




** 3.2 GETTING STARTED **
** Alcune operazioni preliminari **

*version 12.1 

pwd
ls
cd "F:\longi\appendice"
global ap F:\longi\data 

** Alcune impostazioni **
set memory 500m
set dp comma
set more off
help set

** Creazione di un log file **
help log
capture log close
log using "LogAppendice.log", replace


**Aprire e salvare i dati **
use $ap/carriereIT_spell.dta, clear
save carriereIT_spell_new.dta, replace


** 4 L'ISPEZIONE DEI DATI **
** L'ISPEZIONE DEI DATI (I) **
browse
edit
describe
list
list id empstat

** BOX: specificare una lista di variabili **
describe genere age bcoho casmin
describe genere-casmin
describe t*
describe _all

** Ordinare i dati  **
sort id ts 
list id ts tf empstat dur in 1/20, sepby(id)

* BOX: "in" e "if" 
list id ts tf empstat dur in 1/20, sepby(id)
list id ts tf empstat dur  in 1
tabulate empstat if genere==1
tabulate empstat if genere==1 & age<=25


** L'ISPEZIONE DELLE VARIABILI **
codebook dur casmin
summarize dur
summarize dur, detail
tabulate bcoho
tab1 bcoho-cnordsud 


** 5 MANIPOLARE I DATI. ASPETTI GENERALI **
** 5.1 SELEZIONE SU OSSERVAZIONI (CASI) E VARIABILI ** 
tabulate bcoho
tabulate bcoho, nolab 
keep if bcoho > 4  // keep if bcoho >=5
drop if bcoho<=4 
drop father isco88
describe
compress
describe
help erase
help operators

** 5.2 VARIABILI: ISPEZIONARE, MODIFICARE E CREARE VARIABILI ** 
tabulate empstat
tab empstat // per la versione del comando breve 
generate status = empstat  // questa crea la nuova variabile "status" 
recode status (22 = 0) (11 12 13 = 1) (21 = 2) (31 32 33 = 3)
label define status_l 0 "Ricerca primo lavoro" 1 "Occupato" ///
	2 "Disoccupato" 3 "Inattivo"
label value status status_l
label variable status "Status occupazionale"
tab status
* il cross tab 
tab status empstat 
tab status genere, col
tab genere status, row
/*Alternativa
recode empstat (22 = 0 "Ricerca primo lavoro") (11 12 13 = 1 "Occupato") ///
	(21 = 2 "Disoccupato") (31 32 33 = 3 "Inattivo"), generate(status)
*/

** BOX: nomi delle variabili e visualizzazione dei valori **
rename age et
tabulate casmin
tabulate casmin, nolab
describe casmin
label list casmin
labelbook casmin
numlabel casmin, add
tabulate casmin

** Creare variabili in modo pi complesso ** 
egen et_media = mean(et)
tabulate et_media
bys id: egen totdur = sum(dur)
generate occupato = 1 if status==1
bys id: egen ep_occ = count(occupato)

save carriereIT_spell_new, replace 

** BOX: factor variables **
use $ap\es_factor_variables, clear
regress logsalario donna superiore laurea eta
regress logsalario donna i.istruzione eta
regress logsalario i.donna i.istruzione c.eta


** 5.3 LA GESTIONE DEI VALORI MANCANTI (missings) **
use carriereIT_spell_new, clear
codebook cnordsud 
tabulate cnordsud, missing
tabulate cnordsud, nolab
mvdecode cnordsud, mv(999=.a \ 99=.)
codebook cnordsud

tabulate casmin if cnordsud>0 
tabulate casmin if cnordsud>0 & cnordsud<.
*--> lo stesso risultato si ottiene con *
tab casmin if cnordsud==1  // opure con 
tabulate casmin if cnordsud>0 & !missing(cnordsud)

/* Alternative
recode cnordsud (999=.a) (99=.), copyrest  // oppure
replace cnordsud = .a if cnordsud==999
replace cnordsud = . if cnordsud==99
*/


** 6 GESTIONE E MANIPOLAZIONE DEL DATASET **
** AGGIUNGERE CASI **
* --> Append
use $ap\carriereIT_spell_m, clear
describe
tabulate genere
append using $ap\carriereIT_spell_f
describe
tabulate genere

** AGGIUNGERE VARIABILI **
* -->Merge
use $ap\carriereIT_spell_lavoro, clear
use $ap\carriereIT_spell_sd, clear
describe
sort id
merge 1:1 id using $ap\carriereIT_spell_lavoro.dta
browse if _merge==2
tabulate _merge

** VARIABILI NEI DATI LONGITUDINALI **
bysort id: gen des = status[_n+1]
bys id: generate numep = _n
label variable numep "Numero episodio"
tabulate numep
bysort id: generate maxep = _N
list id ts tf status dur des numep maxep in 1/20, sepby(id)

generate evento = 0
replace evento = 1 if des==1

** CAMBIARE LA STRUTTURA DEI DATI **
use $ap\esempi_reddito.dta, clear
reshape wide tenure partime logsalario eta, i(ind) j(tempo)
reshape long tenure partime logsalario eta, i(ind) j(tempo)

** MANEGGIARE VARIABILI CONTINUE **
keep if tempo==2
summarize logsalario, detail
tabstat logsalario, statistics(mean median min max)
tabstat logsalario, statistics(mean median min max) by(donna)
table donna, content(mean logsalario median logsalario min logsalario max logsalario)
table eta, content(mean logsalario) by(donna)
table eta donna, content(mean logsalario)

collapse (mean) logsalario, by(donna eta)
twoway line logsalario eta if donna==0 || line logsalario eta if donna==1 ///
	, legend(label(1 "Uomini") label(2 "Donne") row(1)) ///
	ylabel(, angle(0)) xtitle("Et") ytitle("Log. salario") ///
	title("Salario medio (logaritmo)")
	
	
log close 
